@@ -12,14 +12,12 @@
 #   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 #   Lesser General Public License for more details.
 
-#   You should have received a copy of the GNU Lesser General Public
-#   License along with this library; if not, write to the Free Software
-#   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+#   You should have received a copy of the GNU Lesser General Public License
+#   along with this library; if not, write to the Free Software Foundation,
+#   Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 #
 from .geometry import Point, LineString, LinearRing, Polygon
 from .geometry import MultiPoint, MultiLineString, MultiPolygon
 from .geometry import GeometryCollection
+from .geometry import Feature, FeatureCollection
 from .geometry import as_shape, from_wkt, mapping, orient, signed_area
-
-
-
