@@ -140,8 +140,10 @@ class Feature(_GeoObject):
     _geometry = None
     _feature_id = None
 
-    def __init__(self, geometry, properties={}, feature_id=None, *kwargs):
+    def __init__(self, geometry, properties=None, feature_id=None, *kwargs):
         self._geometry = geometry
+        if properties is None:
+            properties = {}
         self._properties = properties
         self._feature_id = feature_id
 
@@ -160,6 +162,7 @@ class Feature(_GeoObject):
     @property
     def __geo_interface__(self):
         geo_interface = {'type': self._type,
+                         'bbox': self._geometry.bounds,
                          'geometry': self._geometry.__geo_interface__,
                          'properties': self._properties
                          }
@@ -292,6 +295,7 @@ class LineString(_Geometry):
         if self._type and self._geoms:
             return {
                 'type': self._type,
+                'bbox': self.bounds,
                 'coordinates': tuple(self.coords)
             }
 
@@ -449,11 +453,13 @@ class Polygon(_Geometry):
                 coords.append(hole.coords)
             return {
                 'type': self._type,
+                'bbox': self.bounds,
                 'coordinates': tuple(coords)
             }
         elif self._exterior:
             return {
                 'type': self._type,
+                'bbox': self.bounds,
                 'coordinates': (self._exterior.coords,)
             }
 
@@ -570,6 +576,7 @@ class MultiPoint(_Geometry):
     def __geo_interface__(self):
         return {
             'type': self._type,
+            'bbox': self.bounds,
             'coordinates': tuple([g.coords[0] for g in self._geoms])
         }
 
@@ -681,6 +688,7 @@ class MultiLineString(_Geometry):
     def __geo_interface__(self):
         return {
             'type': self._type,
+            'bbox': self.bounds,
             'coordinates': tuple(
                 tuple(c for c in g.coords) for g in self.geoms
             )
@@ -780,6 +788,7 @@ class MultiPolygon(_Geometry):
             allcoords.append(tuple(coords))
         return {
             'type': self._type,
+            'bbox': self.bounds,
             'coordinates': tuple(allcoords)
         }
 
@@ -851,7 +860,7 @@ class MultiPolygon(_Geometry):
             return (minx, miny, maxx, maxy)
 
     def to_wkt(self):
-        pc = ''
+        pc = []
         for geom in self.geoms:
             ec = '(' + ', '.join(
                 [' '.join([str(x) for x in c]) for c in geom.exterior.coords]
@@ -861,8 +870,8 @@ class MultiPolygon(_Geometry):
                 ic += ',(' + ', '.join(
                     [' '.join([str(x) for x in c]) for c in interior.coords]
                 ) + ')'
-            pc += '(' + ec + ic + ')'
-        return self._type.upper() + '(' + pc + ')'
+            pc.append('(' + ec + ic + ')')
+        return self._type.upper() + '(' + ','.join(pc) + ')'
 
     def _set_orientation(self, clockwise=False, exterior=True, interiors=True):
         """ sets the orientation of the coordinates in
@@ -1008,7 +1017,9 @@ class FeatureCollection(_GeoObject):
         gifs = []
         for feature in self._features:
             gifs.append(feature.__geo_interface__)
-        return {'type': self._type, 'features': gifs}
+        return {'type': self._type,
+                'bbox': self.bounds,
+                'features': gifs}
 
     def __init__(self, features):
         self._features = []
